from OFS.SimpleItem import SimpleItem
from Globals import DTMLFile, MessageDialog
from App.Management import Navigation, Tabs
from ZODB import ExportImport
from AccessControl import getSecurityManager

class ZImporter(SimpleItem):

  "ZImporter object"

  meta_type = 'ZImporter'

  manage_options = (
    {'label':'Import',
     'action':'manage_importForm',
     'help':'ZImporter_Import.stx'},
    {'label':'Settings',
     'action':'manage_settingsForm',
     'help':'ZImporter_Settings.stx'},
    ) + SimpleItem.manage_options

  __ac_permissions__ = (
    ('View management screens',
      ('manage_workspace',)),
    ('ZImport zexp Files',
      ('manage_zimportFile','manage_importForm',)),
    ('Change ZImporter Settings',
      ('manage_settings','manage_settingsForm',)),
  )

  # I don't really know what I'm doing, but I think
  # this is necessary
  _p_jar = None

  def __init__(self, id):
    "initialize a new instance of ZImporter"
    self.id = id

#  We now allow index_html to be acquired so the importer is transparent
#
#  def index_html(self):
#    "the View method uses this"
#    return '<html><body>ZImporter index_html</body></html>'

  def manage_addZImporter(self, id, RESPONSE=None):
    "add ZImport to a folder."
    self._setObject(id, ZImporter(id))
    RESPONSE.redirect(id + '/manage_workspace')

  manage_addZImporterForm = DTMLFile('dtml/zimporterAdd', globals())

  def manage_zimportFile(self, REQUEST, set_owner=1):
    '''Do the grunt work.  Take the uploaded file,
    add it to the /import folder and invoke the
    manage_importObject() method upon it.
    This code is mostly borrowed from OFS/ObjectManager.py
    '''
    # Working off code from OFS/ObjectManager.py
    # Even though I don't really understand it.

    # The LORD is my shepherd; I shall not want.
    # He maketh me to lie down in green pastures: 
    #   he leadeth me beside still waters.
    # He restoreth my soul: he leadeth me in the paths 
    #   of righteousness for his name's sake.
    # Yea, though I walk through the valley of the shadow of death, 
    #  I will fear no evil: for thou art with me; 
    #  thy rod and thy staff they comfort me.
    # Thou preparest a table before me in the presence of mine enemies: 
    #   thou annointest my head with oil; my cup runneth over.
    # Surely gooness and mercy shall follow me all the days of my life: 
    #  and I will dwell in the house of the LORD for ever.

    #locate a valid connection
    # Troy - What is a connection?  To ZODB i imagine.
    connection=self._p_jar
    obj=self

    while connection is None:
      obj=obj.aq_parent
      connection=obj._p_jar
    ob=connection.importFile(
      REQUEST.file, customImporters=None)

    if REQUEST: obj._verifyObjectPaste(ob, validate_src=0)
    id=ob.id
    if hasattr(id, 'im_func'): id=id()
    obj._setObject(id, ob, set_owner=set_owner)
    ob=obj._getOb(id)
    ob.manage_changeOwnershipType(explicit=0)

    if REQUEST is not None:
      return MessageDialog(
        title='Object Imported',
	message='<em>%s</em> was sucessfully imported and your server has now been compromised :)' % id,
	action='manage_workspace'
	)

  manage_settingsForm = DTMLFile('dtml/settingsForm', globals())

  def manage_settings(self):
    '''Change settings available for ZImporter'''
    return '<html><body>There are no settings yet.</body></html>'

  def manage_workspace(self, URL1, RESPONSE):
    '''Implement the management interface
    '''
    RESPONSE.redirect(URL1 + '/manage_importForm')

  manage_importForm = DTMLFile('dtml/importForm', globals())


